#!/bin/bash
# pupchecksum.sh
# 01micko 120731 GPL2 (see /usr/share/doc/legal)
# gtkdialog checksum checker
# shinobar: accept parameter
# don570 and shinobar: fix spaces in path name, BASEDIR, more message
# set -x #debug
# radky: 140430 gui modifications

#gettext
MYPATH=$0
MYNAME=$(basename "$0")      
VERSION=0.1

CREDIT="$MYNAME - checksum checker: version $VERSION"
usage() {
  echo $CREDIT
  echo "usage: $APPNAME [FILENAME]"
}
case "$1" in
-v|--version) echo $CREDIT; exit ;;
-*) usage; exit;;
esac
export ENT1="$1"
export ENT2=""
rm -f /tmp/pupchecksum_result
BASEDIR=$(dirname "$ENT1")
[ -d "$BASEDIR" ] || BASEDIR=""
[ -d "$ENT1" ] && BASEDIR="$ENT1"
[ "$BASEDIR" ] || BASEDIR=$HOME
[ "$BASEDIR" ] || BASEDIR="/root"

export TEXTDOMAIN=pupchecksum.sh
export OUTPUT_CHARSET=UTF-8
TITLE="pupChecksum"

#splash screens
export SPLASH1=$(gettext "Please enter a file!")
export _NOFILE=$(gettext "The source file not found!")
export _NGFILE=$(gettext "The source is not a file!")
export _NULL=$(gettext "The source file is null!")
export SPLASH2=$(gettext "Nothing to compare!")
export SPLASH3=$(gettext "Your checksums match")
export SPLASH4=$(gettext "Your checksums DO NOT match")
export SPLASH5=$(gettext "Please wait ...")
export SPLASHT1=$(gettext "Correct")
export SPLASHT2=$(gettext "Wrong!")

#frames, buttons and tool-tip
FRAME1=$(gettext "File Name")
FRAME1a=$(gettext "Hash type")
FRAME2=$(gettext "Checksum")
FRAME3=$(gettext "Compare")
BTN1=$(gettext "Calculate")
BTN2=$(gettext "Compare")
TT=$(gettext "Paste the correct checksum here")

#Check func
checkfunc()
{	
	CHECKSUM=md5sum
	[ "$RB2" = "true" ] && CHECKSUM=sha1sum
	ERRMSG=""
	[ "$ENT1" ] || ERRMSG=$SPLASH1
	[ -s "$ENT1" ] || ERRMSG=$_NULL
	[ -f "$ENT1" ] || ERRMSG=$_NGFILE
	[ -e "$ENT1" ] || ERRMSG=$_NOFILE
	if [ "$ERRMSG" ] ; then
	  gtkdialog-splash -icon gtk-dialog-error -bg orange -timeout 3 -close never -placement top -text "$ERRMSG"
	  return 1
	fi
	gtkdialog-splash -icon gtk-info -bg orange -close never -placement top -text "$SPLASH5" &
	SPID=$!
	$CHECKSUM "$ENT1" > /tmp/pupchecksum
	ENT=$(cat /tmp/pupchecksum)
	rm /tmp/pupchecksum
	export ENT2=${ENT%% *}	#fix dirname with spaces
	echo $ENT2 > /tmp/pupchecksum_result
	kill $SPID
}
export -f checkfunc

#compare
comparefunc()
{
	CHECKSUM=md5sum
	[ "$RB2" = "true" ] && CHECKSUM=sha1sum
	if [ ! "$ENT2" -o ! "$ENT3" ];then gtkdialog-splash -icon gtk-dialog-error -bg orange -timeout 3 -close never -placement top -text "$SPLASH2"
	 else
	 #ENT3=$(echo -n "$ENT3"|sed 's/ //g') #remove whitespace with bad copy/paste
	 ENT3=$(echo $ENT3)	#remove whitespace with bad copy/paste
	 ENT3=${ENT3%% *}	# extract only the checksum
	[ "$ENT2" = "$ENT3" ] && gtkdialog-splash -icon gtk-apply -bg green -close never -placement top -deco "$SPLASHT1" -timeout 4 -text\
	"${CHECKSUM}: $SPLASH3" || gtkdialog-splash -icon gtk-dialog-error -bg pink -close never -placement top -deco "$SPLASHT2" -timeout 4 -text\
	"${CHECKSUM}: $SPLASH4"
	fi
}
export -f comparefunc

ln -snf /usr/share/icons/hash-check.svg /usr/share/icons/hicolor/48x48/apps && gtk-update-icon-cache -f -i /usr/share/icons/hicolor 2>/dev/null

export MAINGUI='<window  title="'"$TITLE"'" icon-name="hash-check" resizable="false">
 <hbox>
  <vbox width-request="335">
   <frame '"$FRAME1"'>
    <hbox>
     <entry fs-action="file" fs-folder="'"$BASEDIR"'">
      <variable>ENT1</variable>
      <default>"'$ENT1'"</default>
      <action>clear:ENT2</action>
     </entry>
     <button>
	  <input file stock="gtk-new"></input>
	  <action>fileselect:ENT1</action>
	 </button>
	</hbox>
   </frame>
   <frame '"$FRAME1a"'>
    <hbox homogeneous="true">
     <radiobutton>
       <label>Md5</label>
       <variable>RB1</variable>
     </radiobutton>
     <radiobutton>
       <label>Sha1</label>
       <variable>RB2</variable>
     </radiobutton>
    </hbox>
   </frame>
   <frame '"$FRAME2"'>
    <entry>
     <variable>ENT2</variable>
     <input>cat /tmp/pupchecksum_result 2>/dev/null</input>
    </entry>
   </frame>
   <frame '"$FRAME3"'>
    <entry tooltip-text="'"$TT"'">
     <variable>ENT3</variable>
    </entry>
   </frame>
  </vbox>
  <vbox>
    <button space-expand="true" space-fill="true" visible="false"><label>" "</label></button>
   <hbox>
    <button width-request="110" image-position="2">
     <label>'"$BTN1"'</label>
     <input file stock="gtk-execute"></input>
     <action>checkfunc '"$ENT1"'</action>
     <action type="refresh">ENT2</action>
     <action>rm /tmp/pupchecksum_result</action>
    </button>
   </hbox>
   <hbox>
    <button width-request="110" image-position="2">
     <label>'"$BTN2"'</label>
     <input file stock="gtk-refresh"></input>
     <action>comparefunc</action>
     </button>
   </hbox>
   <hbox>
    <button width-request="110" image-position="2">
     <label>Close </label>
     <input file stock="gtk-close"></input>
     <action type="exit">quit_now</action>
    </button>
   </hbox>
  </vbox>
 </hbox>
</window>'
for P in gtkdialog4 gtkdialog3 gtkdialog; do
  GTKDIALOG=$(which $P) && break
done
if [ -z "$GTKDIALOG" ]; then
  echo "$MYNAME: error: gtkdialog not found." >&2
  exit 1
fi
[ -f "$ENT1" -a -s "$ENT1" ] && checkfunc "$ENT1"
$GTKDIALOG -p MAINGUI -c
unset MAINGUI
